from flask_wtf import FlaskForm
from wtforms import StringField, PasswordField, BooleanField, SubmitField, SelectField, IntegerField
from wtforms.validators import input_required, Length, EqualTo, NumberRange, Regexp
import datetime

class LoginForm(FlaskForm):
    username = StringField('Username', validators=[input_required(), Length(1, 16)])
    password = PasswordField('Password', validators=[input_required()])
    remember_me = BooleanField('Remember me')
    submit = SubmitField('Submit')

class SignupForm(FlaskForm):
    username = StringField('Username', validators=[input_required(), Length(1, 12)])
    password = PasswordField('Password', validators=[input_required()])
    verifyPassword = PasswordField('Verify password', validators=[input_required(), EqualTo('password', message='Passwords must match')])
    email = StringField('email', validators=[Regexp(regex="^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9-]+(?:\.[a-zA-Z0-9-]+)*$", message = 'has to be a valid email'), input_required()])
    mobile = StringField('mobile', validators=[Regexp(regex='^[+-]?[0-9]+$', message = 'only integers allowed'), input_required(), Length(11, 11)])
    submit = SubmitField('Submit')

class orderByForm(FlaskForm):
    order = SelectField(label = 'Order by', choices=['Default', 'Price Ascending', 'Price Descending'])
    submit = SubmitField('Submit')

class addToCart(FlaskForm):
    choice = SelectField(label='Add to', choices=['Cart', 'Wishlist'])
    submit = SubmitField('Confirm')

class removeFormCart(FlaskForm):
    item_id_remove = StringField('Enter item id of item that you wish to remove')
    clear_all = BooleanField('Clear all?')
    submit = SubmitField('Confirm')

class removeFormWishlist(FlaskForm):
    item_id_remove = StringField('Enter item id of item that you wish to remove')
    clear_all = BooleanField('Clear all?')
    submit = SubmitField('Confirm')

class checkoutForm(FlaskForm):
    security_pin = StringField('Security Pin', validators=[input_required(), Regexp(regex='^[+-]?[0-9]+$', message= 'only integers allowed'), Length(min=3, max=3)])
    card_num = StringField('Card Number', validators=[input_required(), Regexp(regex='^[+-]?[0-9]+$', message = 'only integers allowed'), Length(min=16, max=16)])
    month = IntegerField('Expiry Date', validators=[input_required(), NumberRange(min = 1, max = 12)])
    year = IntegerField(validators=[input_required(), NumberRange(min = datetime.date.today().year, max = 9999)])
    submit = SubmitField('Confirm')

class typeViewForm(FlaskForm):
    type = SelectField(label='product type', choices=['All', 'Fork', 'Frame'])
    submit1 = SubmitField('Submit')

class reviewForm(FlaskForm):
    review = StringField('Enter a review:', validators=[input_required(), Length(min=1, max=300)])
    anonymous = BooleanField('Anonymous?')
    submit1 = SubmitField('Submit')

class emailChangeForm(FlaskForm):
    new_email = StringField('Enter a new email:', validators=[Regexp(regex="^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9-]+(?:\.[a-zA-Z0-9-]+)*$", message = 'has to be a valid email'), input_required()])
    submit1 = SubmitField('Submit')

class mobileChangeForm(FlaskForm):
    new_mobile = StringField('Enter a new mobile:', validators=[Regexp(regex='^[+-]?[0-9]+$', message = 'only integers allowed'), input_required(), Length(11, 11)])
    submit2 = SubmitField('Submit')